pub enum QueryType {
Occlusion,
BinaryOcclusion,
Timestamp,
PipelineStatistics,
VideoDecodeStatistics,
}Expand description
Options for query heap types, and queries
Variants
Occlusion
Used for occlusion query heap or occlusion queries
BinaryOcclusion
Can be used in the same heap as occlusion
Timestamp
Create a heap to contain timestamp queries
PipelineStatistics
Create a heap to contain a structure of PipelineStatistics
VideoDecodeStatistics
Create video decoder statistics query and heap