pub enum ResourceState {
Show 14 variants
RenderTarget,
DepthStencil,
DepthStencilReadOnly,
Present,
UnorderedAccess,
ShaderResource,
VertexConstantBuffer,
IndexBuffer,
ResolveSrc,
ResolveDst,
CopySrc,
CopyDst,
GenericRead,
IndirectArgument,
}Expand description
All possible resource states, some for buffers and some for textures
Variants
RenderTarget
Used for texture only to be written to from fragment shaders
DepthStencil
Used for a texture to be used as a depth stencil buffer
DepthStencilReadOnly
Used for when depth testing is enabled, but depth writes are disabled
Present
Used for swap chain textures only, required before calling swap
UnorderedAccess
Access for read/write from shaders
ShaderResource
Readable from shaders
VertexConstantBuffer
Bindable as a vertex or constant buffer for use in shaders
IndexBuffer
Bindable as an index buffer
ResolveSrc
Used as a source msaa texture to resolve into a non-msaa resource
ResolveDst
Used as a destination sngle sample texture to be resolved into by an msaa resource
CopySrc
Used as a source for copies from into other resources
CopyDst
Used as a destination for copies from other resources or queries
GenericRead
Used as destination to read back data from buffers / queries
IndirectArgument
Used for argument buffer in execute_indirect calls