pub struct DescriptorBinding {
pub visibility: ShaderVisibility,
pub shader_register: u32,
pub register_space: u32,
pub binding_type: DescriptorType,
pub num_descriptors: Option<u32>,
}Expand description
Describes a range of resources for access on the GPU.
Fields
visibility: ShaderVisibilityThe shader stage the resources will be accessible to.
shader_register: u32Register index to bind to (supplied in shader).
register_space: u32Register space to bind to (supplied in shader).
binding_type: DescriptorTypeType of resources in this descriptor binding.
num_descriptors: Option<u32>Number of descriptors in this table, use None for unbounded.