pub struct InputElementInfo {
pub semantic: String,
pub index: u32,
pub format: Format,
pub input_slot: u32,
pub aligned_byte_offset: u32,
pub input_slot_class: InputSlotClass,
pub step_rate: u32,
}Expand description
Describe a single element of an InputLayoutInfo.
Fields
semantic: StringElement semantic ie. POSITION, TEXCOORD, COLOR etc.
index: u32Index of the semantic ie. TEXCOORD0, TEXCOORD1 etc.
format: FormatFormat of the element size and width.
input_slot: u32The vertex buffer slot this buffer will be bound to.
aligned_byte_offset: u32Aligned byte offset of this element from the start of the struct.
input_slot_class: InputSlotClassVertex or Instance stride.
step_rate: u32Rate at which to step vertices.