pub struct PipelineLayout {
pub bindings: Option<Vec<DescriptorBinding>>,
pub push_constants: Option<Vec<PushConstantInfo>>,
pub static_samplers: Option<Vec<SamplerBinding>>,
}Expand description
PipelineLayout is required to create a pipeline it describes the layout of resources for access on the GPU.
Fields
bindings: Option<Vec<DescriptorBinding>>Vector of DescriptorBinding which are arrays of textures, samplers or structured buffers, etc
push_constants: Option<Vec<PushConstantInfo>>Small amounts of data that can be pushed into a command buffer and available as data in shaders
static_samplers: Option<Vec<SamplerBinding>>Static samplers that come along with the pipeline,