pub struct PushConstantInfo {
pub visibility: ShaderVisibility,
pub shader_register: u32,
pub register_space: u32,
pub num_values: u32,
}Expand description
Describes space in the shader to send data to via CmdBuf::push_constants.
Fields
visibility: ShaderVisibilityThe shader stage the constants will be accessible to.
shader_register: u32Register index to bind to (supplied in shader).
register_space: u32Register space to bind to (supplied in shader).
num_values: u32Number of 32-bit values to push.