pub struct SamplerBinding {
pub visibility: ShaderVisibility,
pub shader_register: u32,
pub register_space: u32,
pub sampler_info: SamplerInfo,
}Expand description
Individual sampler state binding for use in static samplers in a PipelineLayout.
Fields
visibility: ShaderVisibilityThe shader stage the sampler will be accessible to
shader_register: u32Register index to bind to (supplied in shader)
register_space: u32Register space to bind to (supplied in shader)
sampler_info: SamplerInfoSampler Info