pub struct AppInfo {
pub name: String,
pub window: bool,
pub num_buffers: u32,
pub dpi_aware: bool,
}Expand description
Information to describe the Application properties
Fields
name: StringName of the application
window: boolSet to true to create a default window
num_buffers: u32Specify the number of buffers in the swap chain
dpi_aware: boolSignify if this app wants to be dpi aware