WindowInfo

Struct WindowInfo 

pub struct WindowInfo<A: App> {
    pub title: String,
    pub rect: Rect<i32>,
    pub style: WindowStyleFlags,
    pub parent_handle: Option<A::NativeHandle>,
}
Filled out to specify various window parameters when a window is created by App::create_window

Fields

title: String

Title appears in the title bar of the window

rect: Rect<i32>

Specify the position and size of the window

style: WindowStyleFlags

Specify window styles

parent_handle: Option<A::NativeHandle>

Specify a parent handle for child windows (optional)