Module plugin

Module plugin 

Trait’s and macros to assist the creation of plugins in other dynamically loaded libraries

Structs

PluginReloadResponder
General dll plugin responder, will check for source code changes and run cargo build to re-build the library

Traits

Plugin
Public trait for defining a plugin in a another library implement this trait and instantiate it with hotline_plugin!

Functions

build_all
Utility function to build all plugins, this can be used to bootstrap them if they don’t exist

Type Aliases

PluginInstance
Plugin instances are crated by the Plugin::create function, created on the heap and passed around as a void* through the hotline_plugin macro to become a Plugin trait