View

Struct View 

pub struct View<D: Device> {
    pub graph_pass_name: String,
    pub pmfx_view_name: String,
    pub name_hash: PmfxHash,
    pub colour_hash: u32,
    pub pass: D::RenderPass,
    pub viewport: Viewport,
    pub scissor_rect: ScissorRect,
    pub blit_dimension: Vec2f,
    pub cmd_buf: D::CmdBuf,
    pub camera: String,
    pub view_pipeline: String,
    pub use_indices: Vec<ResourceUse>,
}
Everything you need to render a world view; command buffers will be automatically reset and submitted for you.

Fields

graph_pass_name: String

Name of the graph view instance, this is the same as the key that is stored in the pmfx views map.

pmfx_view_name: String

Name of the pmfx view, this is the source view (camera, render targets)

name_hash: PmfxHash

Hash of the view name

colour_hash: u32

Colour hash (for debug markers, derived from name)

pass: D::RenderPass

A pre-built render pass: multiple colour targets and depth possible

viewport: Viewport

Pre-calculated viewport based on the output dimensions of the render target adjusted for user data from .pmfx

scissor_rect: ScissorRect

Pre-calculated viewport based on the output dimensions of the render target adjusted for user data from .pmfx

blit_dimension: Vec2f

Dimension of a resource for use when blitting

cmd_buf: D::CmdBuf

A command buffer ready to be used to buffer draw / render commands

camera: String

Name of camera this view intends to be used with

view_pipeline: String

This is the name of a single pipeline used for all draw calls in the view. supplied in data as pipelines: ["name"]

use_indices: Vec<ResourceUse>