pub struct MapInfo {
pub subresource: u32,
pub read_start: usize,
pub read_end: usize,
}Expand description
Info to control mapping of resources for read/write access
Fields
subresource: u32Sub resource to map ie. mip level, cubemap face, array slice
read_start: usizeRange start of data we wish to read, for write-only access supply 0
read_end: usizeRange end of data we wish to read, for write only access supply 0, to read the whole resource supply usize::MAX