pub struct TextureInfo {
pub tex_type: TextureType,
pub format: Format,
pub width: u64,
pub height: u64,
pub depth: u32,
pub array_layers: u32,
pub mip_levels: u32,
pub samples: u32,
pub usage: TextureUsage,
pub initial_state: ResourceState,
}Expand description
Information to create a pipeline through Device::create_texture.
Fields
tex_type: TextureTypeTexture type
format: FormatTexture format
width: u64Width of the image in texels
height: u64Height of the image in texels for TextureType::Texture2D and Texture3D use 1 for Texture1D
depth: u32Depth of the image in slices of (width x height) for TextureType::Texture3D only (use 1 other wise)
array_layers: u32Number of array levels or slices for Texture1D or Texture2D arrays. use 1 otherwise
mip_levels: u32Number of mip levels in the image
samples: u32Number of MSAA samples
usage: TextureUsageIndicate how this texture will be used on the GPU
initial_state: ResourceStateInitial state to start image transition barriers before state